# `leddite`
The `leddite` project provides an easy to use library and hardware designs, to build and interact with AdaFruit Neopixel led strips. The library provides high-level abstractions that make it easier to display user-specified contents. It also provides a command-line tool and REST API, Documentation links provided below.
